@@ -196,14 +196,14 @@ class Register extends SiteController
 				$eview->option     = $this->_option;
 				$eview->controller = $this->_controller;
 				$eview->sitename   = Config::get('sitename');
-				$eview->xprofile   = $target_xprofile;
+				$eview->xprofile   = $xprofile;
 				$eview->baseURL    = $this->baseURL;
 				$message = $eview->loadTemplate();
 				$message = str_replace("\n", "\r\n", $message);
 
 				$msg = new \Hubzero\Mail\Message();
 				$msg->setSubject($subject)
-				    ->addTo($target_xprofile->get('email'))
+				    ->addTo($xprofile->get('email'))
 				    ->addFrom(Config::get('mailfrom'), Config::get('sitename') . ' Administrator')
 				    ->addHeader('X-Component', $this->_option)
 				    ->setBody($message);
@@ -225,7 +225,7 @@ class Register extends SiteController
 			$eaview->option     = $this->_option;
 			$eaview->controller = $this->_controller;
 			$eaview->sitename   = Config::get('sitename');
-			$eaview->xprofile   = $target_xprofile;
+			$eaview->xprofile   = $xprofile;
 			$eaview->baseURL    = $this->baseURL;
 			$message = $eaview->loadTemplate();
 			$message = str_replace("\n", "\r\n", $message);
@@ -263,14 +263,14 @@ class Register extends SiteController
 				$eview->option     = $this->_option;
 				$eview->controller = $this->_controller;
 				$eview->sitename   = Config::get('sitename');
-				$eview->xprofile   = $target_profile;
+				$eview->xprofile   = $xprofile;
 				$eview->baseURL    = $this->baseURL;
 				$message = $eview->loadTemplate();
 				$message = str_replace("\n", "\r\n", $message);
 
 				$msg = new \Hubzero\Mail\Message();
 				$msg->setSubject($subject)
-				    ->addTo($target_xprofile->get('email'))
+				    ->addTo($xprofile->get('email'))
 				    ->addFrom(Config::get('mailfrom'), Config::get('sitename') . ' Administrator')
 				    ->addHeader('X-Component', $this->_option)
 				    ->setBody($message);
@@ -292,7 +292,7 @@ class Register extends SiteController
 			$eaview->option     = $this->_option;
 			$eaview->controller = $this->_controller;
 			$eaview->sitename   = Config::get('sitename');
-			$eaview->xprofile   = $target_xprofile;
+			$eaview->xprofile   = $xprofile;
 			$eaview->baseURL    = $this->baseURL;
 			$message = $eaview->loadTemplate();
 			$message = str_replace("\n", "\r\n", $message);
